# Companies House API Wrapper
[![Upload Python Package](https://github.com/Companies-Insight/chaw/actions/workflows/python-publish.yml/badge.svg)](https://github.com/Companies-Insight/chaw/actions/workflows/python-publish.yml)
